router\_tools
=============

|Latest PyPI version| |Latest Travis CI build status|

A simple tools for router maintain.

Usage
=====

Installation
============

Requirements
------------

Licence
=======

.. |Latest PyPI version| image:: https://img.shields.io/pypi/v/router_tools.svg
   :target: https://pypi.python.org/pypi/router_tools
.. |Latest Travis CI build status| image:: https://travis-ci.org/renweibo/router_tools.png
   :target: https://travis-ci.org/renweibo/router_tools
